---
title: Choosing an Operating System
description: Browse through bullet points that detail the strengths and weaknesses of the different operating systems that Install Doctor supports. If you are unsure, use this page to help you choose which operating system to start with when using Install Doctor.
sidebar_label: Choosing an OS
slug: /getting-started/choosing-os
---

Install Doctor is regularly tested on the x86-64 variants of Arch Linux, CentOS, Debian, Fedora, macOS, Qubes, Ubuntu, and Windows. If you are planning on using or already using Install Doctor, you might re-think what operating system you want to use. Qubes is perhaps the most interesting operating system to choose but there is a learning curve involved. To help you in your journey, information about what makes each supported operating system unique and why you would want to use it is provided below.

## Arch Linux

<picture>
  <source src="/docs/screenshots/archlinux.png" type="image/png" />
  <source src="/docs/screenshots/archlinux.webm" type="image/webm" />
  <img src="/docs/screenshots/archlinux.png" alt="Archlinux desktop screenshot" loading="eager" />
</picture>

Arch Linux is a lightweight and highly customizable Linux distribution that follows the KISS (Keep It Simple, Stupid) philosophy. One of the unique aspects of Arch Linux is its rolling-release model, which means that instead of releasing major versions with new features and updates, the operating system is continuously updated with the latest software and patches.

Here are some reasons why you might want to use Arch Linux:

1. **Customizability**: Arch Linux allows users to customize every aspect of their system, from the desktop environment to the kernel. This makes it a popular choice among advanced users who want to create a personalized computing experience.
2. **Bleeding-edge software**: Because Arch Linux is a rolling-release distribution, it offers the latest software updates and patches, making it an excellent choice for those who want to stay up-to-date with the latest technologies.
3. **Lightweight and minimalistic**: Arch Linux is designed to be lightweight and minimalistic, which means that it runs fast and requires fewer resources than other Linux distributions.
4. **Documentation and community support**: Arch Linux has an extensive wiki that provides detailed documentation on installation, configuration, and troubleshooting. Additionally, there is a large and active community of users who are willing to help with any issues that may arise.
5. **Educational value**: Using Arch Linux requires a certain level of technical expertise and knowledge, which can be a valuable learning experience for those who want to deepen their understanding of Linux and open-source software.

Overall, Arch Linux is an excellent choice for advanced users who value customizability, bleeding-edge software, and a minimalistic computing experience. However, it may not be the best option for beginners or those who require a more user-friendly operating system.

## CentOS

<picture>
  <source src="/docs/screenshots/centos.png" type="image/png" />
  <source src="/docs/screenshots/centos.webm" type="image/webm" />
  <img src="/docs/screenshots/centos.png" alt="CentOS desktop screenshot" loading="lazy" />
</picture>

CentOS is a free and open-source Linux distribution that is based on the source code of Red Hat Enterprise Linux (RHEL). Here are some of the unique aspects of CentOS and why you might want to use it:

1. **Stability**: CentOS is known for its stability and reliability, making it an excellent choice for servers and other mission-critical systems where downtime is not acceptable. It is based on the same codebase as RHEL, which is known for its enterprise-grade stability.
2. **Security**: CentOS has a strong focus on security and includes many security features that are designed to protect against vulnerabilities and attacks. Additionally, it provides regular security updates to ensure that the system is always up-to-date and secure.
3. **Compatibility**: Because CentOS is based on the same codebase as RHEL, it is highly compatible with RHEL and other RHEL-based distributions. This makes it a popular choice for organizations that require compatibility with RHEL or need to run software that is certified for use with RHEL.
4. **Community support**: CentOS has a large and active community of users who are willing to help with any issues that may arise. This includes forums, documentation, and support from CentOS developers and contributors.
5. **Free and open-source**: CentOS is a free and open-source distribution, which means that it can be used, modified, and distributed without any licensing fees or restrictions. This makes it an excellent choice for organizations that require a reliable and secure operating system without incurring licensing costs.

Overall, CentOS is an excellent choice for those who value stability, security, compatibility, and community support. It is particularly well-suited for servers and other mission-critical systems where reliability and security are essential. Additionally, CentOS's focus on free and open-source software makes it a popular choice among users who are committed to the principles of open-source software.

## Debian

<picture>
  <source src="/docs/screenshots/debian.png" type="image/png" />
  <source src="/docs/screenshots/debian.webm" type="image/webm" />
  <img src="/docs/screenshots/debian.png" alt="Debian desktop screenshot" loading="lazy" />
</picture>

Debian is a free and open-source Linux distribution that is known for its stability, security, and extensive package library. Here are some of the unique aspects of Debian and why you might want to use it:

1. **Stability**: Debian is designed to be highly stable and reliable, making it an excellent choice for servers, mission-critical systems, and other applications where downtime is not acceptable.
2. **Security**: Debian has a strong focus on security and includes many security features that are designed to protect against vulnerabilities and attacks. It also provides regular security updates to ensure that the system is always up-to-date and secure.
3. **Extensive package library**: Debian has a vast package library that includes over 50,000 software packages, making it easy to find and install the software you need. Additionally, Debian provides multiple package management tools, such as apt and dpkg, which make it easy to manage software installations and updates.
4. **Community support**: Debian has a large and active community of users who are willing to help with any issues that may arise. This includes forums, documentation, and support from Debian developers and contributors.
5. **Customizability**: Debian is highly customizable, and users can choose from a range of desktop environments and other software packages to create a customized system that meets their specific needs.

Overall, Debian is an excellent choice for those who value stability, security, and an extensive package library. It is particularly well-suited for servers and other mission-critical systems where reliability and security are essential. Additionally, Debian's focus on free and open-source software makes it a popular choice among users who are committed to the principles of open-source software.

## Fedora

<picture>
  <source src="/docs/screenshots/fedora.png" type="image/png" />
  <source src="/docs/screenshots/fedora.webm" type="image/webm" />
  <img src="/docs/screenshots/fedora.png" alt="Fedora desktop screenshot" loading="lazy" />
</picture>

Fedora is a free and open-source Linux distribution that is known for its cutting-edge features and emphasis on innovation. Here are some of the unique aspects of Fedora and why you might want to use it:

1. **Cutting-edge features**: Fedora is known for its focus on cutting-edge technologies and features. It is often one of the first distributions to incorporate new features and technologies, making it a popular choice for early adopters and developers.
2. **Community-driven**: Fedora is developed by a community of developers and contributors who work together to create a high-quality, free and open-source operating system. This community-driven approach ensures that Fedora is always evolving and improving, and that it remains true to its open-source roots.
3. **Customizability**: Fedora is highly customizable and allows users to choose from a range of desktop environments, software packages, and other features to create a customized system that meets their specific needs.
4. **Developer-friendly**: Fedora is a popular choice among developers because of its focus on cutting-edge technologies and development tools. It includes many development tools and libraries out of the box, making it easy for developers to get started with software development.
5. **Security**: Fedora has a strong focus on security and includes many security features that are designed to protect against vulnerabilities and attacks. Additionally, it provides regular security updates to ensure that the system is always up-to-date and secure.

Overall, Fedora is an excellent choice for those who value cutting-edge features, community-driven development, customizability, and developer-friendly tools. It is particularly well-suited for developers and early adopters who want to stay up-to-date with the latest technologies and features. Additionally, Fedora's focus on free and open-source software makes it a popular choice among users who are committed to the principles of open-source software.

## macOS

<picture>
  <source src="/docs/screenshots/macos.png" type="image/png" />
  <source src="/docs/screenshots/macos.webm" type="image/webm" />
  <img src="/docs/screenshots/macos.png" alt="macOS desktop screenshot" loading="lazy" />
</picture>

macOS is a proprietary operating system developed by Apple for its Macintosh line of computers. Here are some of the unique aspects of macOS and why you might want to use it:

1. **Integration with Apple ecosystem**: macOS is designed to work seamlessly with other Apple products, such as iPhones, iPads, and Apple Watches. This integration allows users to easily share files, messages, and other data across devices.
2. **User interface**: macOS has a user-friendly interface that is easy to use and aesthetically pleasing. It also includes many built-in features, such as Spotlight search and Siri, that make it easy to find files and perform tasks.
3. **Security**: macOS has a strong focus on security and includes many security features, such as Gatekeeper and FileVault, that are designed to protect against malware and other threats.
4. **Built-in apps**: macOS includes many built-in apps, such as Safari, iTunes, and iMovie, that are well-designed and easy to use. Additionally, macOS provides access to the App Store, which offers a wide range of third-party apps.
5. **Unix-based**: macOS is based on Unix, which means that it includes many powerful command-line tools and is highly customizable for advanced users and developers.

Overall, macOS is an excellent choice for those who value integration with the Apple ecosystem, a user-friendly interface, security, and built-in apps. It is particularly well-suited for creative professionals, such as graphic designers and video editors, who rely on Apple's software and hardware ecosystem. Additionally, macOS's Unix-based architecture makes it a popular choice among developers who want a powerful command-line interface and customization options.

## Qubes

<picture>
  <source src="/docs/screenshots/qubes.png" type="image/png" />
  <source src="/docs/screenshots/qubes.webm" type="image/webm" />
  <img src="/docs/screenshots/qubes.png" alt="Qubes desktop screenshot" loading="lazy" />
</picture>

Qubes OS is a free and open-source operating system that is designed to provide strong security and isolation between applications and activities. Here are some of the unique aspects of Qubes OS and why you might want to use it:

1. **Security**: Qubes OS is designed to provide strong security and isolation between applications and activities. It uses a unique architecture that runs each application in its own virtual machine, providing isolation and preventing malware from spreading between applications.
2. **Privacy**: Qubes OS includes many privacy features that are designed to protect against surveillance and data collection. For example, it includes a Tor Browser that can be used to browse the internet anonymously.
3. **Customizability**: Qubes OS is highly customizable and allows users to create customized environments for different activities. For example, users can create a separate virtual machine for online banking, ensuring that their financial data is kept separate and secure.
4. **Developer-friendly**: Qubes OS is a popular choice among developers because of its focus on security and customizability. It includes many development tools and libraries out of the box, making it easy for developers to get started with software development.
5. **Virtualization**: Qubes OS is based on the Xen hypervisor, which allows it to run multiple virtual machines simultaneously. This makes it easy to create isolated environments for different activities and provides an extra layer of security.

Overall, Qubes OS is an excellent choice for those who value strong security, privacy, customizability, and virtualization. It is particularly well-suited for those who handle sensitive information or perform activities that require a high degree of security, such as journalists, activists, and government employees. Additionally, Qubes OS's focus on open-source software and developer-friendly tools make it a popular choice among developers who are committed to the principles of open-source software.

## Ubuntu

<picture>
  <source src="/docs/screenshots/ubuntu.png" type="image/png" />
  <source src="/docs/screenshots/ubuntu.webm" type="image/webm" />
  <img src="/docs/screenshots/ubuntu.png" alt="Ubuntu desktop screenshot" loading="lazy" />
</picture>

Ubuntu is a popular and user-friendly Linux distribution that is known for its ease of use, extensive software library, and community support. Here are some of the unique aspects of Ubuntu and why you might want to use it:

1. **User-friendly**: Ubuntu has a simple and intuitive interface that makes it easy for beginners to use. It is also designed to be compatible with a wide range of hardware, which makes it a popular choice for desktops and laptops.
2. **Extensive software library**: Ubuntu has a vast software library that includes thousands of free and open-source applications. This means that users can easily find and install the software they need without having to pay for expensive proprietary software.
3. **Community support**: Ubuntu has a large and active community of users who are willing to help with any issues that may arise. This includes forums, documentation, and support from Canonical, the company behind Ubuntu.
4. **Security**: Ubuntu is known for its strong security features, which are designed to protect users from viruses, malware, and other security threats. This makes it a popular choice for businesses and organizations that require a secure operating system.
5. **Customizability**: While Ubuntu is designed to be user-friendly, it also allows for a high degree of customization. Users can easily modify the appearance of the desktop, install new software, and customize the system to meet their specific needs.

Overall, Ubuntu is an excellent choice for beginners and advanced users who value ease of use, a vast software library, community support, security, and customizability. It is also a popular choice for businesses and organizations that require a secure and reliable operating system.

## Windows

<picture>
  <source src="/docs/screenshots/windows.png" type="image/png" />
  <source src="/docs/screenshots/windows.webm" type="image/webm" />
  <img src="/docs/screenshots/windows.png" alt="Windows 11 desktop screenshot" loading="lazy" />
</picture>

Windows 11 is a proprietary operating system developed by Microsoft and is the successor to Windows 10. Here are some of the unique aspects of Windows 11 and why you might want to use it:

1. **Redesigned user interface**: Windows 11 features a redesigned user interface that is more modern and streamlined than previous versions of Windows. It includes a new Start menu, a centered taskbar, and new icons, making it more visually appealing and easier to use.
2. **Integration with Microsoft services**: Windows 11 is designed to work seamlessly with other Microsoft services, such as OneDrive and Microsoft Teams. This integration allows users to easily access and share files across devices and collaborate with others.
3. **Improved performance**: Windows 11 is designed to be faster and more efficient than previous versions of Windows. It includes many performance improvements, such as better memory management and faster boot times, making it a good choice for those who want a fast and responsive operating system.
4. **Gaming features**: Windows 11 includes many features that are designed to enhance gaming performance, such as Auto HDR and DirectStorage. It also includes Xbox Game Pass integration, which allows users to easily access and play a wide range of games.
5. **Security**: Windows 11 includes many security features, such as hardware-based security and improved ransomware protection, that are designed to protect against malware and other threats.

Overall, Windows 11 is an excellent choice for those who value a modern and streamlined user interface, integration with Microsoft services, improved performance, and gaming features. It is particularly well-suited for gamers and creative professionals who rely on Microsoft software and services. Additionally, Windows 11's focus on security makes it a good choice for those who want a secure and reliable operating system.
